%{
This script is an example to use the individual colorimetric observer with
Monte Carlo simulation


<Input>
n_population: # of population
fs: field size (visual angle in degree)
list_Age: % age distribution, can be a single number if interested in a specific age group


<Output>
LMS_All(79x3xn): area-normalized lms-CMFs (cone fundamentals) for "n_population" observers
dim1: wavelength sampling from 390nm to 780nm at 5nm interval
dim2: i-th cone(L,M,S)
dim3: i-th observer

var_age(1xn): randomly generated age for i-th observer

vAll(nx8): randomly generated eight physiological parameters for each row
row: i-th observer


The example here generates 50 sets of CMFs to simulate 50 observers with
age ranging from 20 to 30 for field size of 2-degree

Alternative to "fnc_genMonteCarloObs.m", one can use
"fnc_genMonteCarloObs_USCensusAgeDist.m" to generate CMFs using US Census
2010 age distribution. In this case, the "list_Age" input is replaced by
the US Census age distribution. 


%}

clear all; 
n_population = 50; % # of population
fs = 2; % field size (visual angle in degree)
list_Age = [20:1:30]; % age distribution

[LMS_All, var_age, vAll ] = fnc_genMonteCarloObs( n_population, list_Age, fs); 
% [LMS_All, var_age, vAll ] = fnc_genMonteCarloObs_USCensusAgeDist( n_population, fs); % Monte Carlo Observers using US Census Age Distribution





%% Plot

figure; hold on; grid on; 
k = 1; plot(390:5:780, squeeze(LMS_All(:,k,:)), 'Color', 'r'); 
k = 2; plot(390:5:780, squeeze(LMS_All(:,k,:)), 'Color', 'g'); 
k = 3; plot(390:5:780, squeeze(LMS_All(:,k,:)), 'Color', 'b'); 

